@@ -61,7 +61,7 @@ where
 ///```
 ///use flowync::Flower;
 ///
-///fn main() {
+///fn _main() {
 ///    let flower = Flower::<i32, String>::new(1);
 ///    std::thread::spawn({
 ///        let handle = flower.handle();
@@ -87,8 +87,7 @@ where
 ///    let mut exit = false;
 ///
 ///    loop {
-///        // instead of polling the mutex over and over,
-///        // the fn will be activated automatically if the handle sending or return a value
+///        // Instead of polling the mutex over and over, check if the flower is_active()
 ///        // and will deactivate itself if the result value successfully received.
 ///        // Note: this fn is non-blocking (won't block the current thread).
 ///        if flower.is_active() {
@@ -184,16 +183,15 @@ where
     }
 
     /// Try receive the flower channel value
-    pub fn try_recv(&self, f: impl FnOnce(Option<SOME>) -> ()) -> &Self {
+    pub fn try_recv(&self, f: impl FnOnce(Option<SOME>)) -> &Self {
         if self.state.channel_present.load(Ordering::Relaxed) {
             let result = self.state.mtx.lock().0.take();
             self.state.channel_present.store(false, Ordering::Relaxed);
             if self.awaiting.1.load(Ordering::Relaxed) {
                 let mut mg_opt_waker = self.awaiting.0.lock();
                 self.awaiting.1.store(false, Ordering::Relaxed);
-                match mg_opt_waker.take() {
-                    Some(waker) => waker.wake(),
-                    _ => (),
+                if let Some(waker) = mg_opt_waker.take() {
+                    waker.wake();
                 }
             } else {
                 self.state.cvar.notify_one();
@@ -206,7 +204,7 @@ where
     }
 
     /// Process the flower result
-    pub fn on_complete(&self, f: impl FnOnce(Result<OK, String>) -> ()) {
+    pub fn on_complete(&self, f: impl FnOnce(Result<OK, String>)) {
         if self.state.result_ready.load(Ordering::Relaxed) {
             let mut result = self.state.mtx.lock();
             let (_, ok, error) = &mut *result;
@@ -373,13 +371,11 @@ where
     OK: Clone + Send + Sync + 'static,
 {
     fn drop(&mut self) {
-        if thread::panicking() {
-            if !self.state.result_ready.load(Ordering::Relaxed) {
-                self.err(format!(
-                    "the flower handle with id: {} error, the thread panicked maybe?",
-                    self.id
-                ));
-            }
+        if thread::panicking() && !self.state.result_ready.load(Ordering::Relaxed) {
+            self.err(format!(
+                "the flower handle with id: {} error, the thread panicked maybe?",
+                self.id
+            ));
         }
     }
 }
